==> igniteui-react-core-18.1.2.tgz: package/esm5/lib/WebComponentBoolValueChangedEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebComponentBoolValueChangedEventArgsDescription } from "./WebComponentBoolValueChangedEventArgsDescription";
/**
 * @hidden
 */
var WebComponentBoolValueChangedEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebComponentBoolValueChangedEventArgsDescriptionMetadata, _super);
    function WebComponentBoolValueChangedEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebComponentBoolValueChangedEventArgsDescriptionMetadata.b = function (a) {
        if (WebComponentBoolValueChangedEventArgsDescriptionMetadata.a == null) {
            WebComponentBoolValueChangedEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebComponentBoolValueChangedEventArgsDescriptionMetadata.c(WebComponentBoolValueChangedEventArgsDescriptionMetadata.a);
        }
        if (a.j(WebComponentBoolValueChangedEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.y(WebComponentBoolValueChangedEventArgsDescriptionMetadata.a);
    };
    WebComponentBoolValueChangedEventArgsDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:ComponentBoolValueChangedEventArgs");
        a.item("Detail", "Boolean");
    };
    WebComponentBoolValueChangedEventArgsDescriptionMetadata.d = function (a) {
        WebComponentBoolValueChangedEventArgsDescriptionMetadata.b(a);
        a.aa("WebComponentBoolValueChangedEventArgs", function () { return new WebComponentBoolValueChangedEventArgsDescription(); });
        a.z("WebComponentBoolValueChangedEventArgs", WebComponentBoolValueChangedEventArgsDescriptionMetadata.a);
    };
    WebComponentBoolValueChangedEventArgsDescriptionMetadata.$t = markType(WebComponentBoolValueChangedEventArgsDescriptionMetadata, 'WebComponentBoolValueChangedEventArgsDescriptionMetadata');
    WebComponentBoolValueChangedEventArgsDescriptionMetadata.a = null;
    return WebComponentBoolValueChangedEventArgsDescriptionMetadata;
}(Base));
export { WebComponentBoolValueChangedEventArgsDescriptionMetadata };

==> igniteui-react-core-18.1.3.tgz: package/esm5/lib/WebComponentBoolValueChangedEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebComponentBoolValueChangedEventArgsDescription } from "./WebComponentBoolValueChangedEventArgsDescription";
/**
 * @hidden
 */
var WebComponentBoolValueChangedEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebComponentBoolValueChangedEventArgsDescriptionMetadata, _super);
    function WebComponentBoolValueChangedEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebComponentBoolValueChangedEventArgsDescriptionMetadata.b = function (a) {
        if (WebComponentBoolValueChangedEventArgsDescriptionMetadata.a == null) {
            WebComponentBoolValueChangedEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebComponentBoolValueChangedEventArgsDescriptionMetadata.c(WebComponentBoolValueChangedEventArgsDescriptionMetadata.a);
        }
        if (a.k(WebComponentBoolValueChangedEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.aa(WebComponentBoolValueChangedEventArgsDescriptionMetadata.a);
    };
    WebComponentBoolValueChangedEventArgsDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:ComponentBoolValueChangedEventArgs");
        a.item("__skipModuleRegisterWebComponents", "Boolean");
        a.item("__importTypesWebComponents", "String:igniteui-webcomponents");
        a.item("Detail", "Boolean");
    };
    WebComponentBoolValueChangedEventArgsDescriptionMetadata.d = function (a) {
        WebComponentBoolValueChangedEventArgsDescriptionMetadata.b(a);
        a.ac("WebComponentBoolValueChangedEventArgs", function () { return new WebComponentBoolValueChangedEventArgsDescription(); });
        a.ab("WebComponentBoolValueChangedEventArgs", WebComponentBoolValueChangedEventArgsDescriptionMetadata.a);
    };
    WebComponentBoolValueChangedEventArgsDescriptionMetadata.$t = markType(WebComponentBoolValueChangedEventArgsDescriptionMetadata, 'WebComponentBoolValueChangedEventArgsDescriptionMetadata');
    WebComponentBoolValueChangedEventArgsDescriptionMetadata.a = null;
    return WebComponentBoolValueChangedEventArgsDescriptionMetadata;
}(Base));
export { WebComponentBoolValueChangedEventArgsDescriptionMetadata };
